#! /usr/bin/env python3
from schmeckels.models import Tag, Transaction
from schmeckels.helper import get_session, format_amount
import sys
import click
from jinja2 import Environment, FileSystemLoader
from sqlalchemy import func, and_
from weasyprint import HTML
from sqlalchemy import func
from weasyprint import HTML
from datetime import date
from pprint import pprint


@click.command(name="report")
@click.option("--profile", "-p")
@click.option("--year", "-y")
def command(profile, year):
    if not year:
        year = date.today().year()

    start_date = date(day=1, month=1, year=int(year))
    end_date = date(day=1, month=12, year=int(year))

    # Get a list of all tags
    session = get_session(profile)
    tags = session.query(Tag).filter_by(reporting=True).all()
    data = {"Einnahmen": {}, "Ausgaben": {}}

    for tag in tags:
        name = tag.name.split(":")[1]
        tag_sum = (
            session.query(func.sum(Transaction.amount))
            .filter(and_(Transaction.date >= start_date, Transaction.date <= end_date))
            .filter(Transaction.tags.any(id=tag.id))
            .first()[0]
        )

        if tag_sum:
            if float(tag_sum) > 0:
                data["Einnahmen"][name] = format_amount(tag_sum)
            else:
                data["Ausgaben"][name] = format_amount(tag_sum)

    pprint(data)
    context = {
        "year": year,
        "tags": data,
        "sum_in": sum([float(v) for k, v in data["Einnahmen"].items()]),
        "sum_out": sum([float(v) for k, v in data["Ausgaben"].items()]),
    }
    context["diff"] = context["sum_in"] + context["sum_out"]

    filename = "output/report_{}_{}.pdf".format(profile, year)
    env = Environment(loader=FileSystemLoader("schmeckels/templates/"))
    template = env.get_template("report.tpl")
    html_out = template.render(context)
    HTML(string=html_out).write_pdf(filename)
    print("Report saved to {}".format(filename))
